==> MetaboDynamics_0.99.9.tar.gz: MetaboDynamics/R/plot_ORA.R <==
#' Plot results of over-representation analysis with ORA_hypergeometric()
#'
#' @param ORA result dataframe from ORA_hypergeometric()
#'
#' @return a plot of the over-representation analysis
#' @export
#' @import ggplot2
#' @seealso [ORA_hypergeometric()]
#' @examples
#' data("cluster")
#' head(cluster)
#' data("modules_compounds")
#' head(modules_compounds)
#' data("metabolite_modules")
#' head(metabolite_modules)
#' ORA <- ORA_hypergeometric(
#'   background = modules_compounds,
#'   annotations = metabolite_modules, clusters = cluster,
#'   tested_column = "middle_hierarchy"
#' )
#' plot_ORA(ORA)
plot_ORA <- function(ORA) {
  # bind variables to function
  OvE_gen <- NULL
  module_name <- NULL
  OvE_gen_lower <- NULL
  OvE_gen_higher <- NULL
  OvE_gen_median <- NULL
  cluster <- NULL
  condition <- NULL

  # input check
  if (!is.data.frame(ORA)) {
    stop("'ORA' must be a dataframe obtained by ORA_hypergeometric()")
  }



  a_clusters <- ORA
  plot <- ggplot(
    a_clusters,
    aes(x = log(OvE_gen), y = module_name, col = col)
  ) +
    geom_errorbarh(aes(xmin = log(OvE_gen_lower), xmax = log(OvE_gen_higher))) +
    geom_point(aes(x = log(OvE_gen_median))) +
    geom_vline(xintercept = 0, linetype = "dashed") +
    theme_bw() +
    scale_color_manual(values = c("ICR includes 0" = "black", "ICR>0" = "green", "ICR<0" = "red")) +
    xlab("log(p(OvE))") +
    guides(col = "none") +
    facet_grid(cols = vars(cluster), rows = vars(condition)) +
    ggtitle(
      "hypergeometric ORA",
      "median and 95% interquantile range, panels=clusterID"
    )
  return(plot)
}

==> MetaboDynamics_0.99.11.tar.gz: MetaboDynamics/R/plot_ORA.R <==
#' Plot results of over-representation analysis with ORA_hypergeometric()
#'
#' @param ORA result dataframe from ORA_hypergeometric()
#'
#' @return a plot of the over-representation analysis
#' @export
#' @import ggplot2
#' @import dplyr
#' @seealso [ORA_hypergeometric()]
#' @examples
#' data("cluster")
#' head(cluster)
#' data("modules_compounds")
#' head(modules_compounds)
#' data("metabolite_modules")
#' head(metabolite_modules)
#' ORA <- ORA_hypergeometric(
#'   background = modules_compounds,
#'   annotations = metabolite_modules, clusters = cluster,
#'   tested_column = "middle_hierarchy"
#' )
#' plot_ORA(ORA)
plot_ORA <- function(ORA) {
  # bind variables to function
  OvE_gen <- NULL
  module_name <- NULL
  OvE_gen_lower <- NULL
  OvE_gen_higher <- NULL
  OvE_gen_median <- NULL
  cluster <- NULL
  condition <- NULL

  # input check
  if (!is.data.frame(ORA)) {
    stop("'ORA' must be a dataframe obtained by ORA_hypergeometric()")
  }

  a_clusters <- ORA

  # get module name (in ORA_hypergeometric this is the 3rd column of the result)
  module_name <- colnames(a_clusters)[3]
  module_name <- as.symbol(module_name)
  module_name <- enquo(module_name)

  # reduce rows for faster plotting
  a_clusters <- a_clusters %>% select(
    condition, cluster, !!module_name, OvE_gen,
    OvE_gen_median, OvE_gen_lower,
    OvE_gen_higher
  )
  a_clusters <- unique(a_clusters)

  # color code for visualization
  a_clusters <- a_clusters %>% mutate(col = ifelse(log(OvE_gen_higher) < 0,
    "ICR<0",
    ifelse(log(OvE_gen_lower) > 0,
      "ICR>0", "ICR includes 0"
    )
  ))

  plot <- ggplot(
    a_clusters,
    aes(x = log(as.numeric(OvE_gen)), y = (!!module_name), col = col)
  ) +
    geom_errorbarh(aes(
      xmin = log(as.numeric(OvE_gen_lower)),
      xmax = log(as.numeric(OvE_gen_higher))
    )) +
    geom_point(aes(x = log(as.numeric(OvE_gen_median)))) +
    geom_vline(xintercept = 0, linetype = "dashed") +
    theme_bw() +
    scale_color_manual(values = c("ICR includes 0" = "black", "ICR>0" = "green", "ICR<0" = "red")) +
    xlab("log(p(OvE))") +
    guides(col = "none") +
    facet_grid(cols = vars(cluster), rows = vars(condition)) +
    ggtitle(
      "hypergeometric ORA",
      "median and 95% interquantile range, panels=clusterID"
    )
  return(plot)
}
